import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';

/// According to Nissim, Flutter uses a specific rendering method for WebViews,
/// where WebViews can have any height, the memory signature is just for 1 page height.
///
/// De-facto:
/// - The device crashes every time since a very large (10000 for example) height of WebView is larger than screen height, causing this issue:
///    -- W/PlatformViewsController: Creating a virtual display of size: [1080, 30000] may result in problems(https://github.com/flutter/flutter/issues/2897).It is larger than the device screen size: [1080, 1776]
///
class InfiniteWVSingleChildScrollViewTest extends StatelessWidget {
  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: _getContentColumn(),
    );
  }

  Widget _buildSeparator() {
    return Container(
      height: 8,
      width: 512,
      color: Color.fromARGB(255, 50, 50, 50),
    );
  }

  Widget _getContentColumn() {
    return Center(
     child: Column(
         mainAxisAlignment: MainAxisAlignment.start,
         mainAxisSize: MainAxisSize.max,
         crossAxisAlignment: CrossAxisAlignment.stretch,
         children: [
           _buildSeparator(),
           _buildTaboolaFlutterLogo(),
           _buildSeparator(),
           _buildSeparator(),
           _buildTaboolaFlutterLogo(),
           _buildSeparator(),
           _buildSeparator(),
           _buildTaboolaFlutterLogo(),
           _buildSeparator(),
           TestWebView(),
           _buildSeparator(),
           _buildTaboolaFlutterLogo(),
           _buildSeparator(),
         ]),
    );
  }

  Widget _buildTaboolaFlutterLogo() {
    return Container(
      color: Color.fromARGB(255, 230, 241, 255),
      height: 300,
      child: Image(
        image: AssetImage('images/flutter_taboola_logo.png'),
        alignment: Alignment.center,
      ),
    );
  }
}

class TestWebView extends StatelessWidget {
  WebView _webView = new WebView(
    initialUrl: "https://news.google.com/", //Infinite content
    javascriptMode: JavascriptMode.unrestricted,
  );

  @override
  Widget build(BuildContext context) {
//    TODO: Find a way to layout this webview with infinite height

    return Container (
      height: 10000,
      child: Column(
        children: [
          Expanded(
            child: _webView
          )
        ]
      ),
    );


//    return Column(
//      mainAxisSize: MainAxisSize.max,
//      crossAxisAlignment: CrossAxisAlignment.stretch,
////      height: 3000,
////      width: 400,
////      child: _webView,
//      children: <Widget>[
//        _webView
//      ],
//    );
  }
}
