import 'dart:convert';

import 'package:webview_flutter/webview_flutter.dart';

class WebViewManager {
  WebViewManager(this.didChangeHeightOfPlacement, this.didFailToLoadPlacementError, this.didClickOnItem);

  WebViewController controller;

  // JS calling Native
  void _onRenderSuccess(String placement, double height) => {};

  void _onRenderFailure(String placement, String error) => {};

  bool _onClick(String title, String pageUrl, String loggerUrl, bool organic, String itemId, String placement) {
    print("test: $title, $pageUrl, $loggerUrl, $organic, $itemId, $placement");
    return true;
  }

  void _onAttributionClick(String url) => {};

  String _getDeviceData() => "";

  String _getLogLevel() => "";

  String _getExternalRects() => "";

  // Native calling JS
  void notifyExternalRects() => {};

  void fireClickEvent() => {};

  // Callbacks
  final void Function(String, double) didChangeHeightOfPlacement;
  final void Function(String, String) didFailToLoadPlacementError;
  final void Function(String, String, String, bool) didClickOnItem;

  JavascriptChannel javascriptChannel() {
    return JavascriptChannel(
        name: "TaboolaBridge",
        onMessageReceived: (JavascriptMessage result) {
          Map<String, dynamic> messageMap = jsonDecode(result.message);
          String action = messageMap["action"];
          String promiseId = messageMap["promiseId"];
          List parameters = messageMap["parameters"];
          print("message ${result.message}");
          _callNativeFunctionFromJS(action, promiseId, parameters);
        });
  }

  void _callNativeFunctionFromJS(String action, String promiseId, List parameters) {
    Function func;
    switch (action) {
      case "onRenderSuccess":
        func = _onRenderSuccess;
        break;
      case "onRenderFailure":
        func = _onRenderFailure;
        break;
      case "onClick":
        func = _onClick;
        break;
      case "onAttributionClick":
        func = _onAttributionClick;
        break;
      case "getDeviceData":
        func = _getDeviceData;
        break;
      case "getLogLevel":
        func = _getLogLevel;
        break;
      case "getExternalRects":
        func = _getExternalRects;
        break;
      default:
        return;
    }
    var returnValue = Function.apply(func, parameters);
    controller.evaluateJavascript("webkitMessageHandler().resolvePromise('$promiseId',$returnValue)");
  }
}
